@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef GRAVATARCONFIGURESETTINGSDIALOG_H
-#define GRAVATARCONFIGURESETTINGSDIALOG_H
+#pragma once
 
 #include "gravatar_export.h"
 #include <QDialog>
@@ -19,7 +18,7 @@ class GRAVATAR_EXPORT GravatarConfigureSettingsDialog : public QDialog
     Q_OBJECT
 public:
     explicit GravatarConfigureSettingsDialog(QWidget *parent = nullptr);
-    ~GravatarConfigureSettingsDialog();
+    ~GravatarConfigureSettingsDialog() override;
 
 private:
     void slotRestoreDefault();
@@ -29,4 +28,3 @@ private:
 };
 }
 
-#endif // GRAVATARCONFIGURESETTINGSDIALOG_H
